package my.example;

import fr.opensagres.xdocreport.converter.ConverterTypeTo;
import fr.opensagres.xdocreport.converter.Options;
import fr.opensagres.xdocreport.core.XDocReportException;
import fr.opensagres.xdocreport.core.document.SyntaxKind;
import fr.opensagres.xdocreport.document.IXDocReport;
import fr.opensagres.xdocreport.document.registry.XDocReportRegistry;
import fr.opensagres.xdocreport.template.IContext;
import fr.opensagres.xdocreport.template.TemplateEngineKind;
import fr.opensagres.xdocreport.template.formatter.FieldsMetadata;

import java.io.*;

public class ODTHTMLFreemarker
{

    public static void main( String[] args )
    {
        try
        {

            InputStream in = ODTHTMLFreemarker.class.getResourceAsStream("/document.odt");
            IXDocReport report = XDocReportRegistry.getRegistry().loadReport( in, TemplateEngineKind.Freemarker );

            // 2) Create fields metadata to manage text styling
            FieldsMetadata metadata = report.createFieldsMetadata();
            metadata.addFieldAsTextStyling( "comments_html", SyntaxKind.Html );

            // 3) Create context Java model
            IContext context = report.createContext();

            context.put( "comments_html", 
                "<h2>Lorem ipsum dolor sit <em>amet, consectetur adipiscing</em> elit</h2><p>laborum." + 
                "</p><p></p><p></p><h2>Cláusula de (<em>livre preenchimento</em>)</h2>" 
            );

            // 4) Generate report by merging Java model with the ODT
            OutputStream outOdt = new FileOutputStream( new File( "ODTTextStylingWithFreemarker_Out.odt" ) );
            report.process( context, outOdt );

            OutputStream outPdf = new FileOutputStream( new File( "ODTTextStylingWithFreemarker_Out.pdf" ) );
            report.convert(context, Options.getTo(ConverterTypeTo.PDF), outPdf);

        }
        catch ( IOException e )
        {
            e.printStackTrace();
        }
        catch ( XDocReportException e )
        {
            e.printStackTrace();
        }
    }
}
